@@ -72,10 +72,11 @@ linkcheck_ignore = [
     re.escape(i)
     for i in (
         r"https://github.com/tox-dev/tox/issues/new?title=Trouble+with+development+environment",
-        r"https://www.unix.org/version2/sample/abort.html",
         r"https://porkbun.com/",  # has captcha on it that makes it return with 405
+        r"https://opensource.org/license/mit",
     )
 ]
+linkcheck_allowed_redirects = {r"https://github.com/tox-dev/tox/issues/\d+": r"https://github.com/tox-dev/tox/pull/\d+"}
 extlinks_detect_hardcoded_links = True
 
 
@@ -87,7 +88,7 @@ def process_signature(  # noqa: PLR0913
     options: Options,
     args: str,  # noqa: ARG001
     retann: str | None,  # noqa: ARG001
-) -> None | tuple[None, None]:
+) -> tuple[None, None] | None:
     # skip-member is not checked for class level docs, so disable via signature processing
     return (None, None) if objtype == "class" and "__init__" in options.get("exclude-members", set()) else None
 
