@@ -1,6 +1,5 @@
-"""
-Expand tox factor expressions to tox environment list.
-"""
+"""Expand tox factor expressions to tox environment list."""
+
 from __future__ import annotations
 
 import re
@@ -22,8 +21,7 @@ def filter_for_env(value: str, name: str | None) -> str:
                 if all((a_name in current) ^ negate for a_name, negate in group):
                     overall.append(content)
                     break  # if any match we use it, and then bail
-    result = "\n".join(overall)
-    return result
+    return "\n".join(overall)
 
 
 def find_envs(value: str) -> Iterator[str]:
@@ -49,7 +47,8 @@ def explode_factor(group: list[tuple[str, bool]]) -> str:
 def expand_factors(value: str) -> Iterator[tuple[list[list[tuple[str, bool]]] | None, str]]:
     for line in value.split("\n"):
         factors: list[list[tuple[str, bool]]] | None = None
-        marker_at, content = line.find(":"), line
+        marker_search = re.search(r":(\s|$)", line)
+        marker_at, content = marker_search.start() if marker_search else -1, line
         if marker_at != -1:
             try:
                 factors = list(find_factor_groups(line[:marker_at].strip()))
@@ -61,22 +60,25 @@ def expand_factors(value: str) -> Iterator[tuple[list[list[tuple[str, bool]]] |
 
 
 def find_factor_groups(value: str) -> Iterator[list[tuple[str, bool]]]:
-    """transform '{py,!pi}-{a,b},c' to [{'py', 'a'}, {'py', 'b'}, {'pi', 'a'}, {'pi', 'b'}, {'c'}]"""
+    """Transform '{py,!pi}-{a,b},c' to [{'py', 'a'}, {'py', 'b'}, {'pi', 'a'}, {'pi', 'b'}, {'c'}]."""
     for env in expand_env_with_negation(value):
         result = [name_with_negate(f) for f in env.split("-")]
         yield result
 
 
+_FACTOR_RE = re.compile(r"!?[\w._][\w._-]*")
+
+
 def expand_env_with_negation(value: str) -> Iterator[str]:
-    """transform '{py,!pi}-{a,b},c' to ['py-a', 'py-b', '!pi-a', '!pi-b', 'c']"""
+    """Transform '{py,!pi}-{a,b},c' to ['py-a', 'py-b', '!pi-a', '!pi-b', 'c']."""
     for key, group in groupby(re.split(r"((?:{[^}]+})+)|,", value), key=bool):
         if key:
             group_str = "".join(group).strip()
             elements = re.split(r"{([^}]+)}", group_str)
-            parts = [re.sub(r"\s+", "", elem).split(",") for elem in elements]
+            parts = [[i.strip() for i in elem.split(",")] for elem in elements]
             for variant in product(*parts):
                 variant_str = "".join(variant)
-                if not re.fullmatch(r"!?[\w._][\w._-]*", variant_str):
+                if not all(_FACTOR_RE.fullmatch(i) for i in variant_str.split("-")):
                     raise ValueError(variant_str)
                 yield variant_str
 
@@ -92,8 +94,8 @@ def is_negated(factor: str) -> bool:
 
 
 __all__ = (
-    "filter_for_env",
-    "find_envs",
     "expand_factors",
     "extend_factors",
+    "filter_for_env",
+    "find_envs",
 )
