@@ -1,4 +1,5 @@
 """Group together configuration values (such as base tox configuration, tox environment configs)."""
+
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
@@ -12,11 +13,15 @@ if TYPE_CHECKING:
     from tox.config.main import Config  # pragma: no cover
 
 
+class CircularChainError(ValueError):
+    """circular chain in config"""
+
+
 T = TypeVar("T")
 V = TypeVar("V")
 
 
-class ConfigDefinition(ABC, Generic[T]):
+class ConfigDefinition(ABC, Generic[T]):  # noqa: PLW1641
     """Abstract base class for configuration definitions."""
 
     def __init__(self, keys: Iterable[str], desc: str) -> None:
@@ -28,13 +33,13 @@ class ConfigDefinition(ABC, Generic[T]):
         raise NotImplementedError
 
     def __eq__(self, o: object) -> bool:
-        return type(self) == type(o) and (self.keys, self.desc) == (o.keys, o.desc)  # type: ignore[attr-defined]
+        return type(self) == type(o) and (self.keys, self.desc) == (o.keys, o.desc)  # type: ignore[attr-defined]  # noqa: E721
 
     def __ne__(self, o: object) -> bool:
         return not (self == o)
 
 
-class ConfigConstantDefinition(ConfigDefinition[T]):
+class ConfigConstantDefinition(ConfigDefinition[T]):  # noqa: PLW1641
     """A configuration definition whose value is defined upfront (such as the tox environment name)."""
 
     def __init__(
@@ -55,13 +60,17 @@ class ConfigConstantDefinition(ConfigDefinition[T]):
         return self.value() if callable(self.value) else self.value
 
     def __eq__(self, o: object) -> bool:
-        return type(self) == type(o) and super().__eq__(o) and self.value == o.value  # type: ignore[attr-defined]
+        return type(self) == type(o) and super().__eq__(o) and self.value == o.value  # type: ignore[attr-defined]  # noqa: E721
+
+    def __repr__(self) -> str:
+        values = ((k, v) for k, v in vars(self).items() if v is not None)
+        return f"{type(self).__name__}({', '.join(f'{k}={v}' for k, v in values)})"
 
 
 _PLACE_HOLDER = object()
 
 
-class ConfigDynamicDefinition(ConfigDefinition[T]):
+class ConfigDynamicDefinition(ConfigDefinition[T]):  # noqa: PLW1641
     """A configuration definition that comes from a source (such as in memory, an ini file, a toml file, etc.)."""
 
     def __init__(  # noqa: PLR0913
@@ -89,10 +98,13 @@ class ConfigDynamicDefinition(ConfigDefinition[T]):
         if self._cache is _PLACE_HOLDER:
             for key, loader in product(self.keys, loaders):
                 chain_key = f"{loader.section.key}.{key}"
-                if chain_key in args.chain:
-                    msg = f"circular chain detected {', '.join(args.chain[args.chain.index(chain_key):])}"
-                    raise ValueError(msg)
-                args.chain.append(chain_key)
+                try:
+                    if chain_key in args.chain:
+                        values = args.chain[args.chain.index(chain_key) :]
+                        msg = f"circular chain detected {', '.join(values)}"
+                        raise CircularChainError(msg)
+                finally:
+                    args.chain.append(chain_key)
                 try:
                     value = loader.load(key, self.of_type, self.factory, conf, args)
                 except KeyError:
@@ -106,23 +118,23 @@ class ConfigDynamicDefinition(ConfigDefinition[T]):
             if self.post_process is not None:
                 value = self.post_process(value)
             self._cache = value
-        return cast(T, self._cache)
+        return cast("T", self._cache)
 
     def __repr__(self) -> str:
-        values = ((k, v) for k, v in vars(self).items() if k != "post_process" and v is not None)
+        values = ((k, v) for k, v in vars(self).items() if k not in {"post_process", "_cache"} and v is not None)
         return f"{type(self).__name__}({', '.join(f'{k}={v}' for k, v in values)})"
 
     def __eq__(self, o: object) -> bool:
         return (
-            type(self) == type(o)
+            type(self) == type(o)  # noqa: E721
             and super().__eq__(o)
             and (self.of_type, self.default, self.post_process) == (o.of_type, o.default, o.post_process)  # type: ignore[attr-defined]
         )
 
 
 __all__ = [
-    "ConfigLoadArgs",
+    "ConfigConstantDefinition",
     "ConfigDefinition",
     "ConfigDynamicDefinition",
-    "ConfigConstantDefinition",
+    "ConfigLoadArgs",
 ]
