@@ -3,10 +3,8 @@ from __future__ import annotations
 import sys
 from abc import ABC, abstractmethod
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Iterator, Mapping, Sequence, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Callable, Generator, Iterator, Mapping, Sequence, TypeVar, cast
 
-from .loader.convert import Factory
-from .loader.section import Section
 from .of_type import ConfigConstantDefinition, ConfigDefinition, ConfigDynamicDefinition, ConfigLoadArgs
 from .set_env import SetEnv
 from .types import EnvList
@@ -15,13 +13,16 @@ if TYPE_CHECKING:
     from tox.config.loader.api import Loader
     from tox.config.main import Config
 
+    from .loader.convert import Factory
+    from .loader.section import Section
+
 V = TypeVar("V")
 
 
 class ConfigSet(ABC):
-    """A set of configuration that belong together (such as a tox environment settings, core tox settings)"""
+    """A set of configuration that belong together (such as a tox environment settings, core tox settings)."""
 
-    def __init__(self, conf: Config, section: Section, env_name: str | None):
+    def __init__(self, conf: Config, section: Section, env_name: str | None) -> None:
         self._section = section
         self._env_name = env_name
         self._conf = conf
@@ -32,6 +33,12 @@ class ConfigSet(ABC):
         self._final = False
         self.register_config()
 
+    def get_configs(self) -> Generator[ConfigDefinition[Any], None, None]:
+        """:return: a mapping of config keys to their definitions"""
+        for k, v in self._defined.items():
+            if k == next(iter(v.keys)):
+                yield v
+
     @abstractmethod
     def register_config(self) -> None:
         raise NotImplementedError
@@ -39,14 +46,14 @@ class ConfigSet(ABC):
     def mark_finalized(self) -> None:
         self._final = True
 
-    def add_config(
+    def add_config(  # noqa: PLR0913
         self,
         keys: str | Sequence[str],
         of_type: type[V],
         default: Callable[[Config, str | None], V] | V,
         desc: str,
         post_process: Callable[[V], V] | None = None,
-        factory: Factory[Any] = None,
+        factory: Factory[Any] | None = None,
     ) -> ConfigDynamicDefinition[V]:
         """
         Add configuration value.
@@ -61,11 +68,12 @@ class ConfigSet(ABC):
         :return: the new dynamic config definition
         """
         if self._final:
-            raise RuntimeError("config set has been marked final and cannot be extended")
+            msg = "config set has been marked final and cannot be extended"
+            raise RuntimeError(msg)
         keys_ = self._make_keys(keys)
         definition = ConfigDynamicDefinition(keys_, desc, of_type, default, post_process, factory)
         result = self._add_conf(keys_, definition)
-        return cast(ConfigDynamicDefinition[V], result)
+        return cast("ConfigDynamicDefinition[V]", result)
 
     def add_constant(self, keys: str | Sequence[str], desc: str, value: V) -> ConfigConstantDefinition[V]:
         """
@@ -77,11 +85,12 @@ class ConfigSet(ABC):
         :return: the new constant config value
         """
         if self._final:
-            raise RuntimeError("config set has been marked final and cannot be extended")
+            msg = "config set has been marked final and cannot be extended"
+            raise RuntimeError(msg)
         keys_ = self._make_keys(keys)
         definition = ConfigConstantDefinition(keys_, desc, value)
         result = self._add_conf(keys_, definition)
-        return cast(ConfigConstantDefinition[V], result)
+        return cast("ConfigConstantDefinition[V]", result)
 
     @staticmethod
     def _make_keys(keys: str | Sequence[str]) -> Sequence[str]:
@@ -91,18 +100,17 @@ class ConfigSet(ABC):
         key = keys[0]
         if key in self._defined:
             self._on_duplicate_conf(key, definition)
-        else:
-            self._keys[key] = None
-            for item in keys:
-                self._alias[item] = key
-            for key in keys:
-                self._defined[key] = definition
+
+        self._keys[key] = None
+        for item in keys:
+            self._alias[item] = key
+        for key in keys:
+            self._defined[key] = definition
         return definition
 
     def _on_duplicate_conf(self, key: str, definition: ConfigDefinition[V]) -> None:
-        earlier = self._defined[key]
-        if definition != earlier:  # pragma: no branch
-            raise ValueError(f"config {key} already defined")
+        msg = f"duplicate configuration definition for {self.name}:\nhas: {self._defined[key]}\nnew: {definition}"
+        raise ValueError(msg)
 
     def __getitem__(self, item: str) -> Any:
         """
@@ -122,7 +130,7 @@ class ConfigSet(ABC):
         :return: the configuration value
         """
         config_definition = self._defined[item]
-        return config_definition.__call__(self._conf, self.loaders, ConfigLoadArgs(chain, self.name, self.env_name))
+        return config_definition.__call__(self._conf, self.loaders, ConfigLoadArgs(chain, self.name, self.env_name))  # noqa: PLC2801
 
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}(loaders={self.loaders!r})"
@@ -170,7 +178,7 @@ class ConfigSet(ABC):
 
 
 class CoreConfigSet(ConfigSet):
-    """Configuration set for the core tox config"""
+    """Configuration set for the core tox config."""
 
     def __init__(self, conf: Config, section: Section, root: Path, src_path: Path) -> None:
         self._root = root
@@ -179,6 +187,15 @@ class CoreConfigSet(ConfigSet):
         desc = "define environments to automatically run"
         self.add_config(keys=["env_list", "envlist"], of_type=EnvList, default=EnvList([]), desc=desc)
 
+    def _default_work_dir(self, conf: Config, env_name: str | None) -> Path:  # noqa: ARG002
+        return cast("Path", self["tox_root"] / ".tox")
+
+    def _default_temp_dir(self, conf: Config, env_name: str | None) -> Path:  # noqa: ARG002
+        return cast("Path", self["work_dir"] / ".tmp")
+
+    def _work_dir_post_process(self, folder: Path) -> Path:
+        return self._conf.work_dir if self._conf.options.work_dir else folder
+
     def register_config(self) -> None:
         self.add_constant(keys=["config_file_path"], desc="path to the configuration file", value=self._src_path)
         self.add_config(
@@ -188,33 +205,31 @@ class CoreConfigSet(ConfigSet):
             desc="the root directory (where the configuration file is found)",
         )
 
-        def work_dir_builder(conf: Config, env_name: str | None) -> Path:  # noqa: U100
-            return (conf.work_dir if conf.work_dir is not None else cast(Path, self["tox_root"])) / ".tox"
-
         self.add_config(
             keys=["work_dir", "toxworkdir"],
             of_type=Path,
-            default=work_dir_builder,
+            default=self._default_work_dir,
+            post_process=self._work_dir_post_process,
             desc="working directory",
         )
         self.add_config(
             keys=["temp_dir"],
             of_type=Path,
-            default=lambda conf, _: cast(Path, self["work_dir"]) / ".tmp",  # noqa: U100, U101
+            default=self._default_temp_dir,
             desc="a folder for temporary files (is not cleaned at start)",
         )
         self.add_constant("host_python", "the host python executable path", sys.executable)
 
-    def _on_duplicate_conf(self, key: str, definition: ConfigDefinition[V]) -> None:  # noqa: U100
+    def _on_duplicate_conf(self, key: str, definition: ConfigDefinition[V]) -> None:
         pass  # core definitions may be defined multiple times as long as all their options match, first defined wins
 
 
 class EnvConfigSet(ConfigSet):
-    """Configuration set for a tox environment"""
+    """Configuration set for a tox environment."""
 
     def __init__(self, conf: Config, section: Section, env_name: str) -> None:
         super().__init__(conf, section, env_name)
-        self.default_set_env_loader: Callable[[], Mapping[str, str]] = lambda: {}
+        self.default_set_env_loader: Callable[[], Mapping[str, str]] = dict
 
     def register_config(self) -> None:
         def set_env_post_process(values: SetEnv) -> SetEnv:
@@ -223,7 +238,17 @@ class EnvConfigSet(ConfigSet):
             return values
 
         def set_env_factory(raw: object) -> SetEnv:
-            if not isinstance(raw, str):
+            if not (
+                isinstance(raw, str)
+                or (isinstance(raw, dict) and all(isinstance(k, str) and isinstance(v, str) for k, v in raw.items()))
+                or (
+                    isinstance(raw, list)
+                    and all(
+                        isinstance(e, dict) and all(isinstance(k, str) and isinstance(v, str) for k, v in e.items())
+                        for e in raw
+                    )
+                )
+            ):
                 raise TypeError(raw)
             return SetEnv(raw, self.name, self.env_name, root)
 
