@@ -32,7 +32,7 @@ DEFAULT_INDEX_URL = "https://pypi.org/simple"
 
 
 class ParsedRequirement:
-    def __init__(self, req: str, options: dict[str, Any], from_file: str, lineno: int) -> None:  # noqa: PLR0912
+    def __init__(self, req: str, options: dict[str, Any], from_file: str, lineno: int) -> None:
         req = req.encode("utf-8").decode("utf-8")
         try:
             self._requirement: Requirement | Path | str = Requirement(req)
@@ -111,7 +111,7 @@ class ParsedRequirement:
 
 
 class ParsedLine:
-    def __init__(  # noqa: PLR0913
+    def __init__(
         self,
         filename: str,
         lineno: int,
@@ -168,7 +168,7 @@ class RequirementsFile:
     @property
     def requirements(self) -> list[ParsedRequirement]:
         self._ensure_requirements_parsed()
-        return cast(List[ParsedRequirement], self._requirements)
+        return cast("List[ParsedRequirement]", self._requirements)
 
     @property
     def _parser(self) -> ArgumentParser:
