@@ -9,6 +9,6 @@ if TYPE_CHECKING:
     from tox.config.main import Config
 
 
-@pytest.fixture()
+@pytest.fixture
 def empty_config(tox_ini_conf: ToxIniCreator) -> Config:
     return tox_ini_conf("")
