@@ -1,9 +1,12 @@
 from __future__ import annotations
 
-from pathlib import Path
+from typing import TYPE_CHECKING
 
 from tox.util.path import ensure_empty_dir
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
 
 def test_ensure_empty_dir_file(tmp_path: Path) -> None:
     dest = tmp_path / "a"
